@@ -118,8 +118,8 @@ class MergeRequestManager(GitlabAPI):
     def show(self):
         """Display all merge requests found with some status information."""
         if self.labels:
-            print("Open merge requests matching labels: [%s]" %
-                  "][".join(self.labels))
+            print("Open merge requests matching labels: "
+                  f"[{']['.join(self.labels)}]")
         else:
             print("Open merge requests: (mergeable, pipeline status)")
 
@@ -129,7 +129,7 @@ class MergeRequestManager(GitlabAPI):
                         'success' else '✗'
             mr_status = '✓' if merge_request.merge_status == \
                         'can_be_merged' else '✗'
-            mr_labels = ' [%s]' % ']['.join(merge_request.labels) \
+            mr_labels = f" [{']['.join(merge_request.labels)}]" \
                         if merge_request.labels else ''
             print(f"{mr_status}{pl_status}"
                   f" {merge_request.references['full']}:"
@@ -138,8 +138,8 @@ class MergeRequestManager(GitlabAPI):
     def merge_all(self):
         """Merge all identified merge requests."""
         if self.labels:
-            print("Merging merge requests that match labels: [%s]" %
-                  "][".join(self.labels))
+            print("Merging merge requests that match labels: "
+                  f"[{']['.join(self.labels)}]")
         else:
             print("Merging merge requests:")
 
@@ -205,8 +205,9 @@ class ProjectManager(GitlabAPI):
                     group.projects.list(search=self.project_filter, all=True,
                                         archived=False):
                 project = Project(self.api, group_project)
-                matched_tags = set(project.topic_list) & set(self.topic_list)
-                if matched_tags or not self.topic_list:
+                topics_match = set(project.topic_list) \
+                    & set(self.topic_list) == set(self.topic_list)
+                if topics_match or not self.topic_list:
                     yield project
 
     def show(self):
@@ -229,7 +230,7 @@ class GroupManager(GitlabAPI):
 
         users = self.api.users.list(username=username)
         if len(users) != 1:
-            raise ValueError('No such user: %s' % username)
+            raise ValueError(f'No such user: {username}')
 
         self.group_filter = group_filter
         self.user = users[0]
